;;; info-rename-buffer.el --- Rename Info buffers to match manuals  -*- lexical-binding:t -*-

;; Copyright (C) 2019 Bruno Félix Rezende Ribeiro <oitofelix@gnu.org>

;; Maintainer: Bruno Félix Rezende Ribeiro <oitofelix@gnu.org>
;; Keywords: help

;; This program is free software: you can redistribute it and/or
;; modify it under the terms of the GNU General Public License as
;; published by the Free Software Foundation, either version 3 of the
;; License, or (at your option) any later version.

;; This program is distributed in the hope that it will be useful, but
;; WITHOUT ANY WARRANTY; without even the implied warranty of
;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
;; General Public License for more details.

;; You should have received a copy of the GNU General Public License
;; along with this program.  If not, see
;; <https://www.gnu.org/licenses/>.

;;; Commentary:

;;; ‘info-rename-buffer-mode’ is a global minor-mode that
;;; automatically renames Info buffers to match their visiting manual.

;;; Code:


;;;###autoload;
(define-minor-mode info-rename-buffer-mode
  "Toggle Info-Rename-Buffer mode on or off.
With a prefix argument ARG, enable Info-Rename-Buffer mode if ARG
is positive, and disable it otherwise.  If called from Lisp,
enable the mode if ARG is omitted or nil, and toggle it if ARG is
‘toggle’.

When Info-Rename-Buffer is enabled, Info buffer's name is
automatically changed to include its currently visiting manual's
name.  See the command \\[info-rename-buffer]."
  :group 'info
  :init-value nil
  :global t
  :require 'info-rename-buffer
  (if info-rename-buffer-mode
      (add-hook 'Info-selection-hook #'info-rename-buffer)
    (remove-hook 'Info-selection-hook #'info-rename-buffer)))


(defun info-rename-buffer ()
  "Rename current Info buffer to match its visiting manual."
  (interactive)
  (unless (ignore-errors
	    (rename-buffer
	     (format "*info %s*" (file-name-base Info-current-file))
	     'unique))
    (user-error "%s" "This is not an Info buffer.")))


(provide 'info-rename-buffer)

;;; info-rename-buffer.el ends here
